@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2014 Bill Wilson
+|  Copyright (C) 1999-2019 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -460,7 +460,7 @@ fs_draw_decal_text(FSmon *fs, gint value)
 	GkrellmDecal		*d;
 	GkrellmTextstyle	ts_save;
 	gchar				buf[128];
-	gint				x_off, w;
+	gint				x_off, w = 0;
 
 	if (value == 0)
 		{
@@ -810,7 +810,7 @@ fs_update(void)
 				if (fs->blocks > 2147483648LL)
 					fs->krell_factor = 1024 * 1024;
 				else if (fs->blocks > 2097152LL)
-					fs->krell_factor = 1024 * 1024;
+					fs->krell_factor = 1024;
 				else
 					fs->krell_factor = 1;
 				}
