@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2014 Bill Wilson
+|  Copyright (C) 1999-2019 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -758,12 +758,13 @@ create_about_tab(GtkWidget *vbox)
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
 
 	buf = g_strdup_printf(_("GKrellM %d.%d.%d%s\nGNU Krell Monitors\n\n"
-				"Copyright (c) 1999-2014 by Bill Wilson\n"
+				"Copyright (c) %s by Bill Wilson\n"
 				"billw@gkrellm.net\n"
 				"http://gkrellm.net\n\n"
 				"Released under the GNU General Public License"),
 				GKRELLM_VERSION_MAJOR, GKRELLM_VERSION_MINOR,
-				GKRELLM_VERSION_REV, GKRELLM_EXTRAVERSION);
+				GKRELLM_VERSION_REV, GKRELLM_EXTRAVERSION,
+				"1999-2019");
 	label = gtk_label_new(buf);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
 	g_free(buf);
@@ -1014,6 +1015,18 @@ N_("\t\\e    draw right justified in the defined field width\n"),
 N_("\t\\.     no-op.  Used to break a string into two strings.\n"),
 N_("\t\\D0   bottom of charts first data view (D2 for second data view ...)\n"),
 N_("\t\\D1   top of charts first data view (D3 for second data view ...)\n"),
+"\n",
+N_("\tText drawn on charts cannot use Pango markup and changing the color\n"),
+N_("\tused for a chart default or alternate font requires editing the theme.\n"),
+"\n",
+
+N_("<h>Panel Labels\n"),
+N_("\tMost panel labels can use Pango markup to customize the font or\n"
+   "\ttext color.  If the Pango markup string requires quote characters some\n"
+   "\tmonitors (eg Sensors) require using single quotes instead of double\n"
+   "\tquotes.  For example, to set a big colored CPU label, use markup:\n"),
+	"\t    <span foreground='cyan'><big>CPU</big></span>\n",
+"\n",
 
 N_("<h>\nCommands\n"),
 N_("\tMany monitors can be configured to launch commands.  Just enter the\n"
@@ -1556,7 +1569,7 @@ gkrellm_save_theme_config(void)
 	gchar	*path;
 
 	/* Assume gkrellm -t is for testing and don't save theme config changes.
-	|  Similary for _GK.demo.
+	|  Similarly for _GK.demo.
 	*/
 	if (!theme_modified || _GK.command_line_theme || _GK.demo || _GK.no_config)
 		return;
@@ -2483,9 +2496,9 @@ static GtkActionEntry ui_entries[] =
     { "ThemeMenuAction", NULL, N_("Theme"),
       NULL, NULL, NULL },
     { "ThemeAltNextAction", NULL, N_("Next"),
-      "Page_Up", NULL, G_CALLBACK(cb_load_theme) },
+      "<shift>Page_Up", NULL, G_CALLBACK(cb_load_theme) },
     { "ThemeAltPrevAction", NULL, N_("Prev"),
-      "Page_Down", NULL, G_CALLBACK(cb_load_theme) },
+      "<shift>Page_Down", NULL, G_CALLBACK(cb_load_theme) },
     { "ThemeNextAction", NULL, N_("Theme next"),
       "<control>Page_Up", NULL, G_CALLBACK(cb_load_theme) },
     { "ThemePrevAction", NULL, N_("Theme prev"),
